@@ -3,7 +3,6 @@
  *  Copyright (c) 2000-2003 by Frank Singleton
  *  Copyright (c) 2000-2010 by Stephane Fillod
  *
- *	$Id: riglist.h,v 1.76 2009-01-29 22:54:40 fillods Exp $
  *
  *   This library is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU Library General Public License as
@@ -59,7 +58,7 @@
 #define RIG_MODEL_ARMSTRONG RIG_MAKE_MODEL(RIG_DUMMY, 3)
 
 	/*
-	 * Yaesu 
+	 * Yaesu
 	 */
 #define RIG_YAESU 1
 #define RIG_BACKEND_YAESU "yaesu"
@@ -94,6 +93,8 @@
 #define RIG_MODEL_FT2000 RIG_MAKE_MODEL(RIG_YAESU, 29)
 #define RIG_MODEL_FT9000 RIG_MAKE_MODEL(RIG_YAESU, 30)
 #define RIG_MODEL_FT980 RIG_MAKE_MODEL(RIG_YAESU, 31)
+#define RIG_MODEL_FTDX5000 RIG_MAKE_MODEL(RIG_YAESU, 32)
+#define RIG_MODEL_VX1700 RIG_MAKE_MODEL(RIG_YAESU, 33)
 
 	/*
 	 * Kenwood
@@ -130,6 +131,7 @@
 #define RIG_MODEL_TS480 RIG_MAKE_MODEL(RIG_KENWOOD, 28)
 #define RIG_MODEL_K3 RIG_MAKE_MODEL(RIG_KENWOOD, 29)
 #define RIG_MODEL_TRC80 RIG_MAKE_MODEL(RIG_KENWOOD, 30)
+#define RIG_MODEL_TS590S RIG_MAKE_MODEL(RIG_KENWOOD, 31)
 
 	/*
 	 * Icom
@@ -241,6 +243,7 @@
 #define RIG_MODEL_AR8600 RIG_MAKE_MODEL(RIG_AOR, 13)
 #define RIG_MODEL_AR5000A RIG_MAKE_MODEL(RIG_AOR, 14)
 #define RIG_MODEL_AR7030P RIG_MAKE_MODEL(RIG_AOR, 15)
+#define RIG_MODEL_SR2200 RIG_MAKE_MODEL(RIG_AOR, 16)
 
 	/*
 	 * JRC
@@ -464,8 +467,11 @@
 #define RIG_MODEL_DDS60 RIG_MAKE_MODEL(RIG_KIT, 6)
 #define RIG_MODEL_ELEKTOR507 RIG_MAKE_MODEL(RIG_KIT, 7)	/* Elektor SDR USB */
 #define RIG_MODEL_MINIVNA RIG_MAKE_MODEL(RIG_KIT, 8)
-#define RIG_MODEL_SI570AVRUSB RIG_MAKE_MODEL(RIG_KIT, 9) /* SoftRock Si570 */
+#define RIG_MODEL_SI570AVRUSB RIG_MAKE_MODEL(RIG_KIT, 9) /* SoftRock Si570 AVR */
 #define RIG_MODEL_PMSDR RIG_MAKE_MODEL(RIG_KIT, 10)
+#define RIG_MODEL_SI570PICUSB RIG_MAKE_MODEL(RIG_KIT, 11) /* SoftRock Si570 PIC */
+#define RIG_MODEL_FIFISDR RIG_MAKE_MODEL(RIG_KIT, 12) /* FiFi-SDR USB */
+#define RIG_MODEL_FUNCUBEDONGLE RIG_MAKE_MODEL(RIG_KIT, 13)	/* FunCUBE Dongle */
 
 	/*
 	 * SW/FM/TV tuner cards supported by Video4Linux,*BSD, ..
@@ -482,6 +488,14 @@
 #define RIG_MODEL_ESMC RIG_MAKE_MODEL(RIG_RS, 1)
 #define RIG_MODEL_EB200 RIG_MAKE_MODEL(RIG_RS, 2)
 
+	/*
+	 * Phillips/Simoco PRM80
+	 */
+#define RIG_PRM80 28
+#define RIG_BACKEND_PRM80 "prm80"
+#define RIG_MODEL_PRM8060 RIG_MAKE_MODEL(RIG_PRM80, 1)
+#define RIG_MODEL_PRM8070 RIG_MAKE_MODEL(RIG_PRM80, 2)
+
 
 	/*
 	 * TODO:
@@ -528,6 +542,7 @@ typedef int rig_model_t;
 		{ RIG_KIT, RIG_BACKEND_KIT }, \
 		{ RIG_TUNER, RIG_BACKEND_TUNER }, \
 		{ RIG_RS, RIG_BACKEND_RS }, \
+		{ RIG_PRM80, RIG_BACKEND_PRM80 }, \
 		{ 0, NULL }, /* end */  \
 }
 
