@@ -2,8 +2,6 @@
  *  Hamlib Kenwood backend - main header
  *  Copyright (c) 2000-2009 by Stephane Fillod
  *
- *	$Id: kenwood.h,v 1.54 2009-02-10 22:48:25 fillods Exp $
- *
  *   This library is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU Library General Public License as
  *   published by the Free Software Foundation; either version 2 of
@@ -32,13 +30,22 @@
 #define EOM_TH '\r'
 
 #define KENWOOD_MODE_TABLE_MAX	10
-#define KENWOOD_MAX_BUF_LEN	50 /* max answer len, arbitrary */
+#define KENWOOD_MAX_BUF_LEN		50 /* max answer len, arbitrary */
 
+
+/* Tokens for Parameters common to multiple rigs.
+ * Use token # >= 1 or <= 100.  Defined here so they will be
+ * available in Kenwood name space.
+ */
 #define TOK_VOICE	TOKEN_BACKEND(1)
 #define TOK_FINE	TOKEN_BACKEND(2)
 #define TOK_XIT		TOKEN_BACKEND(3)
 #define TOK_RIT		TOKEN_BACKEND(4)
 
+/* Token structure assigned to .cfgparams in rig_caps */
+extern const struct confparams kenwood_cfg_params[];
+
+
 /*
  * modes in use by the "MD" command
  */
@@ -61,6 +68,9 @@ struct kenwood_priv_caps {
 struct kenwood_priv_data {
     char info[KENWOOD_MAX_BUF_LEN];
     split_t split;		/* current split state */
+    int k2_ext_lvl;		/* Initial K2 extension level */
+    int k3_ext_lvl;		/* Initial K3 extension level */
+    int k2_md_rtty;		/* K2 RTTY mode available flag, 1 = RTTY, 0 = N/A */
 };
 
 #define kenwood_caps(rig) ((struct kenwood_priv_caps *)(rig)->caps->priv)
@@ -164,26 +174,33 @@ extern const struct rig_caps ts811_caps;
 extern const struct rig_caps r5000_caps;
 
 extern const struct rig_caps ts480_caps;
+extern const struct rig_caps ts590_caps;
+extern const struct rig_caps thf6a_caps;
 
 /* use when not interested in the answer, but want to check its len */
 static int inline kenwood_simple_transaction(RIG *rig, const char *cmd, size_t expected)
 {
-	char buf[10];
-	return kenwood_safe_transaction(rig, cmd, buf, 10, expected);
+	char buf[20];
+	return kenwood_safe_transaction(rig, cmd, buf, sizeof(buf), expected);
 }
 
 /* no answer needed at all */
 static int inline kenwood_simple_cmd(RIG *rig, const char *cmd)
 {
-	char buf[10];
-	return kenwood_safe_transaction(rig, cmd, buf, 10, 0);
+	char buf[20];
+	return kenwood_safe_transaction(rig, cmd, buf, sizeof(buf), 0);
 }
 
 /* answer is the same as the command */
 static int inline kenwood_cmd(RIG *rig, const char *cmd)
 {
-	char buf[10];
-	return kenwood_safe_transaction(rig, cmd, buf, 10, strlen(cmd) + 1);
+	char buf[20];
+	int lenz = strlen(cmd)+1;
+
+	if (lenz > sizeof(buf))
+	  return -RIG_ENOMEM;
+	else
+	  return kenwood_safe_transaction(rig, cmd, buf, sizeof(buf), lenz);
 }
 
 #endif /* _KENWOOD_H */
