@@ -1,8 +1,7 @@
 /*
  *  Hamlib Kenwood backend - TH handheld header
- *  Copyright (c) 2001-2008 by Stephane Fillod
+ *  Copyright (c) 2001-2010 by Stephane Fillod
  *
- *	$Id: th.h,v 1.11 2008-05-04 21:27:26 fillods Exp $
  *
  *   This library is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU Library General Public License as
@@ -21,11 +20,14 @@
  */
 #ifndef __TH_H__
 #define __TH_H__ 1
+
 #include "idx_builtin.h"
 
-#define TH_VER "0.4"
+#define TH_VER "0.5"
 
 extern int th_transaction (RIG *rig, const char *cmdstr, char *data, size_t datasize);
+extern int th_get_vfo_char(RIG *rig, vfo_t *vfo, char *vfoch);
+
 extern int th_decode_event (RIG *rig);
 extern int th_set_freq (RIG *rig, vfo_t vfo, freq_t freq);
 extern int th_get_freq (RIG *rig, vfo_t vfo, freq_t *freq);
@@ -33,7 +35,9 @@ extern int th_set_mode (RIG *rig, vfo_t vfo, rmode_t mode, pbwidth_t width);
 extern int th_get_mode (RIG *rig, vfo_t vfo, rmode_t *mode, pbwidth_t *width);
 extern int th_set_vfo(RIG *rig, vfo_t vfo);
 extern int th_get_vfo(RIG *rig, vfo_t *vfo);
-extern int th_get_vfo_char(RIG *rig, vfo_t *vfo, char *vfoch);
+extern int tm_set_vfo_bc2 (RIG *rig, vfo_t vfo);
+extern int th_set_split_vfo (RIG *rig, vfo_t vfo, split_t split, vfo_t txvfo);
+extern int th_get_split_vfo (RIG *rig, vfo_t vfo, split_t *split, vfo_t *txvfo);
 extern int th_set_trn(RIG *rig, int trn);
 extern int th_get_trn (RIG *rig, int *trn);
 extern int th_set_powerstat (RIG *rig, powerstat_t status);
@@ -46,6 +50,10 @@ extern int th_get_level (RIG *rig, vfo_t vfo, setting_t level, value_t *val);
 extern int th_set_level (RIG *rig, vfo_t vfo, setting_t level, value_t val);
 extern int th_set_ctcss_tone(RIG *rig, vfo_t vfo, tone_t tone);
 extern int th_get_ctcss_tone(RIG *rig, vfo_t vfo, tone_t *tone);
+extern int th_set_ctcss_sql(RIG *rig, vfo_t vfo, tone_t tone);
+extern int th_get_ctcss_sql(RIG *rig, vfo_t vfo, tone_t *tone);
+extern int th_set_dcs_sql(RIG *rig, vfo_t vfo, tone_t code);
+extern int th_get_dcs_sql(RIG *rig, vfo_t vfo, tone_t *code);
 extern const char *th_get_info(RIG *rig);
 extern int th_set_mem(RIG *rig, vfo_t vfo, int ch);
 extern int th_get_mem(RIG *rig, vfo_t vfo, int *ch);
@@ -57,6 +65,7 @@ extern int th_set_channel(RIG *rig, const channel_t *chan);
 extern int th_set_ant (RIG * rig, vfo_t vfo, ant_t ant);
 extern int th_get_ant (RIG * rig, vfo_t vfo, ant_t * ant);
 extern int th_reset(RIG *rig, reset_t reset);
+extern int th_scan(RIG *rig, vfo_t vfo, scan_t scan, int ch);
 
 
 #define TH_CHANNEL_CAPS \
@@ -72,7 +81,7 @@ extern int th_reset(RIG *rig, reset_t reset);
 .ctcss_tone=1,\
 .ctcss_sql=1,\
 .channel_desc=1
-                                                                                
+
 
 #endif /* __TH_H__ */
 /* end of file */
