@@ -1,9 +1,8 @@
 /*
  *  Hamlib Interface - event handling
- *  Copyright (c) 2000-2009 by Stephane Fillod
+ *  Copyright (c) 2000-2010 by Stephane Fillod
  *  Copyright (c) 2000-2003 by Frank Singleton
  *
- *	$Id: event.c,v 1.25 2006-10-15 00:27:51 aa6e Exp $
  *
  *   This library is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU Library General Public License as
@@ -67,6 +66,9 @@
 #define CHECK_RIG_ARG(r) (!(r) || !(r)->caps || !(r)->state.comm_state)
 
 
+#ifdef HAVE_SIGACTION
+static struct sigaction hamlib_trn_oldact, hamlib_trn_poll_oldact;
+
 #ifdef HAVE_SIGINFO_T
 static RETSIGTYPE sa_sigioaction(int signum, siginfo_t *si, void *data);
 static RETSIGTYPE sa_sigalrmaction(int signum, siginfo_t *si, void *data);
@@ -74,9 +76,10 @@ static RETSIGTYPE sa_sigalrmaction(int signum, siginfo_t *si, void *data);
 static RETSIGTYPE sa_sigiohandler(int signum);
 static RETSIGTYPE sa_sigalrmhandler(int signum);
 #endif
+#endif
 
 /* This one should be in an include file */
-int foreach_opened_rig(int (*cfunc)(RIG *, rig_ptr_t),rig_ptr_t data);
+extern int foreach_opened_rig(int (*cfunc)(RIG *, rig_ptr_t),rig_ptr_t data);
 
 /*
  * add_trn_rig
@@ -85,13 +88,15 @@ int foreach_opened_rig(int (*cfunc)(RIG *, rig_ptr_t),rig_ptr_t data);
  */
 int add_trn_rig(RIG *rig)
 {
-#ifndef WIN32
+#ifdef HAVE_SIGACTION
 	struct sigaction act;
 	int status;
 
 		/*
 		 * FIXME: multiple open will register several time SIGIO hndlr
 		 */
+	memset(&act, 0, sizeof(act));
+
 #ifdef HAVE_SIGINFO_T
 	act.sa_sigaction = sa_sigioaction;
 #else
@@ -101,33 +106,33 @@ int add_trn_rig(RIG *rig)
 	sigemptyset(&act.sa_mask);
 
 #if defined(HAVE_SIGINFO_T) && defined(SA_SIGINFO)
-	act.sa_flags = SA_SIGINFO;
+	act.sa_flags = SA_SIGINFO|SA_RESTART;
 #else
-	act.sa_flags = 0;
+	act.sa_flags = SA_RESTART;
 #endif
 
-	status = sigaction(SIGIO, &act, NULL);
+	status = sigaction(SIGIO, &act, &hamlib_trn_oldact);
 	if (status < 0)
-		rig_debug(RIG_DEBUG_ERR,"rig_open sigaction failed: %s\n",
-						strerror(errno));
+		rig_debug(RIG_DEBUG_ERR,"%s: sigaction failed: %s\n",
+						__func__, strerror(errno));
 
 	status = fcntl(rig->state.rigport.fd, F_SETOWN, getpid());
 	if (status < 0)
-		rig_debug(RIG_DEBUG_ERR,"rig_open fcntl SETOWN failed: %s\n",
-						strerror(errno));
+		rig_debug(RIG_DEBUG_ERR,"%s: fcntl SETOWN failed: %s\n",
+						__func__, strerror(errno));
 
 #if defined(HAVE_SIGINFO_T) && defined(O_ASYNC)
 #ifdef F_SETSIG
 	status = fcntl(rig->state.rigport.fd, F_SETSIG, SIGIO);
 	if (status < 0)
-		rig_debug(RIG_DEBUG_ERR,"rig_open fcntl SETSIG failed: %s\n",
-						strerror(errno));
+		rig_debug(RIG_DEBUG_ERR,"%s: fcntl SETSIG failed: %s\n",
+						__func__, strerror(errno));
 #endif
 
 	status = fcntl(rig->state.rigport.fd, F_SETFL, O_ASYNC);
 	if (status < 0)
-		rig_debug(RIG_DEBUG_ERR,"rig_open fcntl SETASYNC failed: %s\n",
-						strerror(errno));
+		rig_debug(RIG_DEBUG_ERR,"%s: fcntl SETASYNC failed: %s\n",
+						__func__, strerror(errno));
 #else
 	return -RIG_ENIMPL;
 #endif
@@ -136,53 +141,9 @@ int add_trn_rig(RIG *rig)
 
 #else
 	return -RIG_ENIMPL;
-#endif	/* !WIN32 */
+#endif	/* !HAVE_SIGACTION */
 }
 
-/*
- * add_trn_poll_rig
- * not exported in Hamlib API.
- */
-int add_trn_poll_rig(RIG *rig)
-{
-#ifndef WIN32
-	struct sigaction act;
-	int status;
-
-		/*
-		 * FIXME: multiple open will register several time SIGIO hndlr
-		 */
-#ifdef HAVE_SIGINFO_T
-	act.sa_sigaction = sa_sigalrmaction;
-#else
-	act.sa_handler = sa_sigalrmhandler;
-#endif
-
-	sigemptyset(&act.sa_mask);
-
-	status = sigaction(SIGALRM, &act, NULL);
-	if (status < 0)
-		rig_debug(RIG_DEBUG_ERR,"%s sigaction failed: %s\n",
-				__FUNCTION__,
-				strerror(errno));
-
-	return RIG_OK;
-
-#else
-	return -RIG_ENIMPL;
-#endif	/* !WIN32 */
-}
-
-/*
- * remove_trn_poll_rig
- * not exported in Hamlib API.
- */
-int remove_trn_poll_rig(RIG *rig)
-{
-	return -RIG_ENIMPL;
-}
-
-
 /*
  * remove_trn_rig
  * not exported in Hamlib API.
@@ -190,13 +151,89 @@ int remove_trn_poll_rig(RIG *rig)
  */
 int remove_trn_rig(RIG *rig)
 {
-	if (rig->caps->transceive == RIG_TRN_RIG)
-		return -RIG_ENIMPL;
+#ifdef HAVE_SIGACTION
+	int status;
 
-	if (rig->state.transceive == RIG_TRN_POLL)
-		return remove_trn_poll_rig(rig);
+    /* assert(rig->caps->transceive == RIG_TRN_RIG); */
 
-	return -RIG_EINVAL;
+#if defined(HAVE_SIGINFO_T) && defined(O_ASYNC)
+	status = fcntl(rig->state.rigport.fd, F_SETFL, 0);
+	if (status < 0)
+		rig_debug(RIG_DEBUG_ERR,"%s: fcntl SETASYNC failed: %s\n",
+						__func__, strerror(errno));
+#endif
+
+	status = sigaction(SIGIO, &hamlib_trn_oldact, NULL);
+	if (status < 0)
+		rig_debug(RIG_DEBUG_ERR,"%s: sigaction failed: %s\n",
+						__func__, strerror(errno));
+
+	return RIG_OK;
+#else
+	return -RIG_ENIMPL;
+#endif	/* !HAVE_SIGACTION */
+}
+
+
+#ifdef HAVE_SIGACTION
+
+/*
+ * add_trn_poll_rig
+ * not exported in Hamlib API.
+ */
+static int add_trn_poll_rig(RIG *rig)
+{
+#ifdef HAVE_SIGACTION
+	struct sigaction act;
+	int status;
+
+		/*
+		 * FIXME: multiple open will register several time SIGALRM hndlr
+		 */
+	memset(&act, 0, sizeof(act));
+
+#ifdef HAVE_SIGINFO_T
+	act.sa_sigaction = sa_sigalrmaction;
+#else
+	act.sa_handler = sa_sigalrmhandler;
+#endif
+	act.sa_flags = SA_RESTART;
+
+	sigemptyset(&act.sa_mask);
+
+	status = sigaction(SIGALRM, &act, &hamlib_trn_poll_oldact);
+	if (status < 0)
+		rig_debug(RIG_DEBUG_ERR,"%s sigaction failed: %s\n",
+				__func__,
+				strerror(errno));
+
+	return RIG_OK;
+
+#else
+	return -RIG_ENIMPL;
+#endif	/* !HAVE_SIGINFO */
+}
+
+/*
+ * remove_trn_poll_rig
+ * not exported in Hamlib API.
+ */
+static int remove_trn_poll_rig(RIG *rig)
+{
+#ifdef HAVE_SIGINFO
+	int status;
+
+	status = sigaction(SIGALRM, &hamlib_trn_poll_oldact, NULL);
+	if (status < 0)
+		rig_debug(RIG_DEBUG_ERR,"%s sigaction failed: %s\n",
+				__func__,
+				strerror(errno));
+
+	return RIG_OK;
+
+#else
+	return -RIG_ENIMPL;
+#endif	/* !HAVE_SIGINFO */
 }
 
 
@@ -276,6 +313,8 @@ static int search_rig_and_poll(RIG *rig, rig_ptr_t data)
 	if (rig->state.hold_decode)
 		return -1;
 
+	rig->state.hold_decode = 2;
+
 	if (rig->caps->get_vfo && rig->callbacks.vfo_event) {
 		vfo_t vfo = RIG_VFO_CURR;
 
@@ -293,7 +332,8 @@ static int search_rig_and_poll(RIG *rig, rig_ptr_t data)
 		retval = rig->caps->get_freq(rig, RIG_VFO_CURR, &freq);
 		if (retval == RIG_OK) {
  			if (freq != rs->current_freq) {
-				rig->callbacks.freq_event(rig, RIG_VFO_CURR, freq, rig->callbacks.freq_arg);
+				rig->callbacks.freq_event(rig, RIG_VFO_CURR,
+						freq, rig->callbacks.freq_arg);
 			}
 	 		rs->current_freq = freq;
 		}
@@ -313,6 +353,8 @@ static int search_rig_and_poll(RIG *rig, rig_ptr_t data)
 		}
 	}
 
+	rig->state.hold_decode = 0;
+
 	return 1;	/* process each opened rig */
 }
 
@@ -363,12 +405,14 @@ static RETSIGTYPE sa_sigalrmaction(int signum, siginfo_t *si, rig_ptr_t data)
 
 static RETSIGTYPE sa_sigalrmhandler(int signum)
 {
-	rig_debug(RIG_DEBUG_TRACE, "sa_sigalrmaction entered\n");
+	rig_debug(RIG_DEBUG_TRACE, "sa_sigalrmhandler entered\n");
 
 	foreach_opened_rig(search_rig_and_poll, NULL);
 }
 
-#endif
+#endif /* !HAVE_SIGINFO_T */
+
+#endif /* HAVE_SIGINFO */
 
 #endif	/* !DOC_HIDDEN */
 
@@ -547,28 +591,43 @@ int HAMLIB_API rig_set_pltune_callback(RIG *rig, pltune_cb_t cb, rig_ptr_t arg)
 int HAMLIB_API rig_set_trn(RIG *rig, int trn)
 {
 	const struct rig_caps *caps;
-	int retcode;
+	int retcode = RIG_OK;
+#ifdef HAVE_SETITIMER
+	struct itimerval value;
+#endif
 
 	if (CHECK_RIG_ARG(rig))
 		return -RIG_EINVAL;
 
 	caps = rig->caps;
 
-	if (trn == RIG_TRN_RIG) {
+	/* detect whether tranceive is active already */
+	if (trn != RIG_TRN_OFF && rig->state.transceive != RIG_TRN_OFF) {
+		if (trn == rig->state.transceive) {
+			return RIG_OK;
+		} else {
+			/* when going POLL<->RIG, transtition to OFF */
+			retcode = rig_set_trn(rig, RIG_TRN_OFF);
+			if (retcode != RIG_OK)
+				return retcode;
+		}
+	}
+
+	switch (trn) {
+	case RIG_TRN_RIG:
 		if (caps->transceive != RIG_TRN_RIG)
 			return -RIG_ENAVAIL;
 
-		if (rig->state.transceive == RIG_TRN_OFF) {
-			retcode = add_trn_rig(rig);
-			if (retcode == RIG_OK && caps->set_trn) {
-				retcode = caps->set_trn(rig, RIG_TRN_RIG);
-			}
-		} else {
-			return -RIG_ECONF;
+		retcode = add_trn_rig(rig);
+		/* some protocols (e.g. CI-V's) offer no way
+		 * to turn on/off the transceive mode */
+		if (retcode == RIG_OK && caps->set_trn) {
+			retcode = caps->set_trn(rig, RIG_TRN_RIG);
 		}
-	} else if (trn == RIG_TRN_POLL) {
+		break;
+
+	case RIG_TRN_POLL:
 #ifdef HAVE_SETITIMER
-		struct itimerval value;
 
 		add_trn_poll_rig(rig);
 
@@ -580,20 +639,21 @@ int HAMLIB_API rig_set_trn(RIG *rig, int trn)
 		retcode = setitimer(ITIMER_REAL, &value, NULL);
 		if (retcode == -1) {
 			rig_debug(RIG_DEBUG_ERR, "%s: setitimer: %s\n",
-					__FUNCTION__,
+					__func__,
 					strerror(errno));
-			remove_trn_rig(rig);
+			remove_trn_poll_rig(rig);
 			return -RIG_EINTERNAL;
 		}
 #else
 		return -RIG_ENAVAIL;
 #endif
-	} else if (trn == RIG_TRN_OFF) {
+		break;
+
+	case RIG_TRN_OFF:
 		if (rig->state.transceive == RIG_TRN_POLL) {
 #ifdef HAVE_SETITIMER
-			struct itimerval value;
 
-			retcode = remove_trn_rig(rig);
+			retcode = remove_trn_poll_rig(rig);
 
 			value.it_value.tv_sec = 0;
 			value.it_value.tv_usec = 0;
@@ -603,25 +663,28 @@ int HAMLIB_API rig_set_trn(RIG *rig, int trn)
 			retcode = setitimer(ITIMER_REAL, &value, NULL);
 			if (retcode == -1) {
 				rig_debug(RIG_DEBUG_ERR, "%s: setitimer: %s\n",
-					__FUNCTION__,
+					__func__,
 					strerror(errno));
 				return -RIG_EINTERNAL;
 			}
 #else
-		return -RIG_ENAVAIL;
+			return -RIG_ENAVAIL;
 #endif
-		} else {
+		} else if (rig->state.transceive == RIG_TRN_RIG) {
 			retcode = remove_trn_rig(rig);
 			if (caps->set_trn && caps->transceive == RIG_TRN_RIG) {
 				retcode = caps->set_trn(rig, RIG_TRN_OFF);
 			}
 		}
-	} else {
+		break;
+
+	default:
 		return -RIG_EINVAL;
 	}
 
 	if (retcode == RIG_OK)
 		rig->state.transceive = trn;
+
 	return retcode;
 }
 
