@@ -481,6 +481,13 @@ int HAMLIB_API rig_open(RIG *rig)
 		if (rs->pttport.fd < 0)
 			rig_debug(RIG_DEBUG_ERR, "Cannot open PTT device \"%s\"\n",
 						rs->pttport.pathname);
+        else {
+			/* Needed on Linux because the kernel forces RTS/DTR at open */
+			if (rs->pttport.type.ptt == RIG_PTT_SERIAL_DTR)
+				ser_set_dtr(&rs->pttport, RIG_PTT_OFF);
+			else if (rs->pttport.type.ptt == RIG_PTT_SERIAL_RTS)
+				ser_set_rts(&rs->pttport, RIG_PTT_OFF);
+		}
 		break;
 	case RIG_PTT_PARALLEL:
 		rs->pttport.fd = par_open(&rs->pttport);
@@ -606,8 +613,12 @@ int HAMLIB_API rig_close(RIG *rig)
 	case RIG_PTT_RIG:
 		break;
 	case RIG_PTT_SERIAL_RTS:
+		ser_set_rts(&rs->pttport, RIG_PTT_OFF);
+		port_close(&rs->pttport, RIG_PORT_SERIAL);
+		break;
 	case RIG_PTT_SERIAL_DTR:
-        port_close(&rs->pttport, RIG_PORT_SERIAL);
+		ser_set_dtr(&rs->pttport, RIG_PTT_OFF);
+		port_close(&rs->pttport, RIG_PORT_SERIAL);
 		break;
 	case RIG_PTT_PARALLEL:
         par_ptt_set(&rs->pttport, RIG_PTT_OFF);
