@@ -102,9 +102,13 @@
 
 /* Timing values in mS */
 
-#define FT450_PACING_INTERVAL                5
-#define FT450_PACING_DEFAULT_VALUE           0
-#define FT450_WRITE_DELAY                    50
+// #define FT450_PACING_INTERVAL                5
+// #define FT450_PACING_DEFAULT_VALUE           0
+
+/* Delay between bytes sent to FT-450
+ * Should not exceed value set in CAT TOT menu (rig default is 10 mSec)
+ */
+#define FT450_WRITE_DELAY                    0
 
 
 /* Delay sequential fast writes */
