@@ -64,7 +64,7 @@ const struct rig_caps ft950_caps = {
     .serial_data_bits =   8,
     .serial_stop_bits =   1,            /* Assumed since manual makes no mention */
     .serial_parity =      RIG_PARITY_NONE,
-    .serial_handshake =   RIG_HANDSHAKE_NONE,
+    .serial_handshake =   RIG_HANDSHAKE_HARDWARE,
     .write_delay =        FT950_WRITE_DELAY,
     .post_write_delay =   FT950_POST_WRITE_DELAY,
     .timeout =            2000,
